/*******************************************************************************
 * Copyright (c) 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     Erich Gamma (erich_gamma@ch.ibm.com) and
 * 	   Kent Beck (kent@threeriversinstitute.org)
 *******************************************************************************/
package org.eclipse.contribution.junit;

import java.io.IOException;
import java.io.PrintWriter;
import java.net.Socket;
import java.net.UnknownHostException;

import junit.framework.AssertionFailedError;
import junit.framework.Test;
import junit.framework.TestListener;
import junit.framework.TestResult;
import junit.framework.TestSuite;

public class SocketTestRunner implements TestListener {
	private int port;
	private Socket socket;
	private PrintWriter writer;
	
	/**
	* The entry point for the test runner.
	* The arguments are:
	* args[0]: the port number to connect to
	* args[1-n]: the name of test classes
	*/
	public static void main(String[] args) {
		new SocketTestRunner().runTests(args);
	}

	private void runTests(String[] args) {
		port= Integer.parseInt(args[0]);
		openClientSocket();
		try {
			TestSuite suite= new TestSuite();
			for (int i= 1; i < args.length; i++)
				suite.addTestSuite(Class.forName(args[i]));
			writer.println("starting tests " + suite.countTestCases());
			TestResult result= new TestResult();
			result.addListener(this);
			suite.run(result);
			writer.println("ending tests");
		} catch (ClassNotFoundException e) {
			System.out.println("Not a class: " + args[1]);
		} finally {
			closeClientSocket();
		}
	}

	private void openClientSocket() {
		for (int i= 0; i < 10; i++) {
			try {
				socket= new Socket("localhost", port);
				writer= new PrintWriter(socket.getOutputStream(), true);
				return;
			} catch (UnknownHostException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
			try {
				Thread.sleep(500);
			} catch (InterruptedException e1) {
			}
		}
	}
	
	private void closeClientSocket() {
		writer.close();
		try {
			socket.close();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	public void addError(Test test, Throwable t) {
		writer.println("failing test " + test);
		t.printStackTrace(writer);
		writer.println("END TRACE");
	}
	
	public void addFailure(Test test, AssertionFailedError t) {
		addError(test, t);
	}
	
	public void endTest(Test test) {
	}
	
	public void startTest(Test test) {
		writer.println("starting test " + test);
	}
}